// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { getTracer } from "@azure/core-tracing";
import { SpanKind } from "@opentelemetry/types";
/**
 * Creates a span using the global tracer.
 * @param name The name of the operation being performed.
 * @param options The options for the underlying http request.
 */
export function createSpan(operationName, options = {}) {
    const tracer = getTracer();
    const tracingOptions = Object.assign({ spanOptions: {} }, options.tracingOptions);
    tracingOptions.spanOptions = Object.assign(Object.assign({}, tracingOptions.spanOptions), { kind: SpanKind.CLIENT });
    const span = tracer.startSpan(`Azure.Identity.${operationName}`, tracingOptions.spanOptions);
    span.setAttribute("component", "identity");
    let newOptions = options;
    if (span.isRecording()) {
        newOptions = Object.assign(Object.assign({}, options), { tracingOptions: Object.assign(Object.assign({}, tracingOptions), { spanOptions: Object.assign(Object.assign({}, tracingOptions.spanOptions), { parent: span }) }) });
    }
    return {
        span,
        options: newOptions
    };
}
//# sourceMappingURL=tracing.js.map